@@ -28,6 +28,7 @@ from waydroid_helper.controller.widgets.decorators import (
     Resizable,
     ResizableDecorator,
 )
+from waydroid_helper.util.log import logger
 
 if TYPE_CHECKING:
     from cairo import Context, Surface
@@ -56,7 +57,6 @@ class Aim(BaseWidget):
         "Controller Widgets",
         "FPS staple: drag to game's view area, pair with Fire for mouse-aim shooting. Resize box to match in-game rotation zone.",
     )
-    WIDGET_VERSION = "1.0"
     IS_REENTRANT = True  # 支持可重入，实现长按瞄准功能
 
     # 固定圆形区域大小
@@ -261,10 +261,10 @@ class Aim(BaseWidget):
             # 超出边界，发送UP事件并重置位置
             await self._send_touch_up(w, h)
             self._current_pos = (float(self.center_x), float(self.center_y))
-            await asyncio.sleep(0.05)
+            # await asyncio.sleep(0.05)
             await self._send_touch_down(w, h)
-            self._current_pos = (float(self.center_x) + dx, float(self.center_y) + dy)
-            await self._send_touch_move(w, h)
+            # self._current_pos = (float(self.center_x) + dx, float(self.center_y) + dy)
+            # await self._send_touch_move(w, h)
             return
 
         # 更新位置并发送MOVE事件
@@ -474,6 +474,7 @@ class Aim(BaseWidget):
             self.event_bus.emit(Event(type=EventType.AIM_TRIGGERED, source=self, data=None))
 
         except Exception as e:
+            logger.error(f"Failed to enter aiming state: {e}")
             await self._set_state(AimState.IDLE)
 
     async def _exit_aiming_state(self) -> None:
