@@ -3,6 +3,7 @@ from .log import logger
 from .subprocess_manager import SubprocessError, SubprocessManager
 from .task import Task
 from .template import template
+from .adb_helper import AdbHelper
 from .weak_ref import \
     connect_weakly  # pyright: ignore[reportUnknownVariableType]
 
@@ -13,5 +14,6 @@ __all__ = [
     'Task',
     'connect_weakly',
     'template',
-    'AbxReader'
+    'AbxReader',
+    'AdbHelper',
 ]
